# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from oslo_log import versionutils

from keystone.auth.plugins import mapped


@versionutils.deprecated(
    versionutils.deprecated.MITAKA,
    what='keystone.auth.plugins.saml2.Saml2',
    in_favor_of='keystone.auth.plugins.mapped.Mapped',
    remove_in=+2)
class Saml2(mapped.Mapped):
    """Provide an entry point to authenticate with SAML2.

    This plugin subclasses ``mapped.Mapped``, and may be specified in
    keystone.conf::

        [auth]
        methods = external,password,token,saml2
        saml2 = keystone.auth.plugins.mapped.Mapped

    """

    pass
